// TemperatureTMP.cpp - Arduino library for retrieving data from Analog Devices TMP Temperature sensors
// Copyright 2013 R den Breejen (info@breematic.nl)
// For more information: variable declaration, changelog,... see bmNTC.h
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

#include <Arduino.h>
#include <bmNTC.h>



/// Constructor
bmNTC::bmNTC()
{
}

/// Begin variables
/// - int ntcPin: number indicating the temperature sensor pin: ANALOG IN
/// - float B: ntc beta value
/// - float R25: ntc resistance 25 degrees celsius
/// - float R1: fixed resistance between vcc and analog input
void bmNTC::begin(int ntcPin,float B,float R25,float R1)
{
  pinMode(ntcPin, INPUT);
  _ntcPin=ntcPin;
  
  _B = B;
  _R25 = R25;
  _R1 = R1;  
}


/// getTemperatureRaw(): Returns the temperature as a raw value: ADC output: 0 -> 1023
int bmNTC::getTemperatureRaw()
{
  return (analogRead(_ntcPin));
}

/// getTemperaturePercentage(): Returns the temperature degrees
float bmNTC::getTemperatureCelcius()
{
	float raw = float(getTemperatureRaw());
    return (1/((log(((raw *_R1)/(1023.0-raw))/_R25)/_B)+(1/298.15))-273.15);
}